@@ -56,14 +56,14 @@ PRELUDE_PLUGIN_OPTION_DECLARE_STRING_CB(xmlmod, xmlmod_plugin_t, logfile)
 static int file_write(void *context, const char *buf, int len) 
 {
         size_t ret;
-        
-        ret = fwrite(buf, 1, len, context);
+
+        ret = fwrite(buf, 1, (size_t) len, context);
         if ( ret != (size_t ) len && ferror((FILE *) context) ) {
                 prelude_log(PRELUDE_LOG_ERR, "could not write IDMEF-XML data: '%s'.\n", strerror(errno));
                 return -1;
         }
                 
-        return 0;
+        return (int) ret;
 }
 
 
@@ -326,10 +326,12 @@ static void process_snmp_service(xmlNodePtr parent, idmef_snmp_service_t *snmp)
                 return;
 
         idmef_content_string(new, "oid", idmef_snmp_service_get_oid(snmp));
-        idmef_content_string(new, "community", idmef_snmp_service_get_community(snmp));
-        idmef_content_string(new, "security_name", idmef_snmp_service_get_security_name(snmp));
-        idmef_content_string(new, "context_name", idmef_snmp_service_get_context_name(snmp));
-        idmef_content_string(new, "context_engine_id", idmef_snmp_service_get_context_engine_id(snmp));
+        idmef_content_generic_optional(new, "messageProcessingModel", "%" PRELUDE_PRIu32, idmef_snmp_service_get_message_processing_model(snmp));
+        idmef_content_generic_optional(new, "securityModel", "%" PRELUDE_PRIu32, idmef_snmp_service_get_security_model(snmp));
+        idmef_content_string(new, "securityName", idmef_snmp_service_get_security_name(snmp));
+        idmef_content_generic_optional(new, "securityLevel", "%" PRELUDE_PRIu32, idmef_snmp_service_get_security_level(snmp));
+        idmef_content_string(new, "contextName", idmef_snmp_service_get_context_name(snmp));
+        idmef_content_string(new, "contextEngineId", idmef_snmp_service_get_context_engine_id(snmp));
         idmef_content_string(new, "command", idmef_snmp_service_get_command(snmp));
 }
 
@@ -886,21 +888,17 @@ static void validate_dtd(xmlmod_plugin_t *plugin, xmlDoc *doc)
 
 
 
-static void dump_to_buffer(xmlmod_plugin_t *plugin, xmlDoc *doc) 
-{
-        xmlNodeDumpOutput(plugin->fd, doc, doc->children, 0, plugin->format, NULL);
-
-	xmlOutputBufferWriteString(plugin->fd, "\n");
-        
-        xmlOutputBufferFlush(plugin->fd);
-}
-
-
-
 static void dump_document(xmlmod_plugin_t *plugin, xmlDoc *doc) 
 {
-        dump_to_buffer(plugin, doc);
-                
+        xmlNodeDumpOutput(plugin->fd, doc, doc->children, 0, plugin->format, NULL);
+        if ( plugin->format )
+	        xmlOutputBufferWriteString(plugin->fd, "\n");
+	        
+        xmlOutputBufferFlush(plugin->fd);
+        
+        if ( plugin->no_buffering )
+                fflush(plugin->fd->context);
+                        
         if ( plugin->idmef_dtd )
                 validate_dtd(plugin, doc);
 }
@@ -953,7 +951,6 @@ static int xmlmod_run(prelude_plugin_instance_t *pi, idmef_message_t *message)
 
 static int xmlmod_init(prelude_plugin_instance_t *pi, prelude_string_t *out)
 {
-        int ret;
         FILE *fd;
         xmlmod_plugin_t *plugin = prelude_plugin_instance_get_plugin_data(pi);
         
@@ -973,12 +970,6 @@ static int xmlmod_init(prelude_plugin_instance_t *pi, prelude_string_t *out)
                 return -1;
         }
         
-        if ( plugin->no_buffering ) {
-                ret = setvbuf(fd, NULL, _IONBF, 0);
-                if ( ret != 0)
-                        prelude_log(PRELUDE_LOG_ERR, "error opening %s for writing.\n", plugin->logfile);
-        }
-        
         plugin->fd->context = fd;
         plugin->fd->writecallback = file_write;
         plugin->fd->closecallback = NULL; /* No close callback */
