@@ -26,9 +26,19 @@
 
 #include <stdio.h>
 #include <sys/types.h>
-#include <sys/time.h>
 #include <netinet/in.h>
 
+#if TIME_WITH_SYS_TIME
+# include <sys/time.h>
+# include <time.h>
+#else
+# if HAVE_SYS_TIME_H
+#  include <sys/time.h>
+# else
+#  include <time.h>
+# endif
+#endif
+
 #include <libprelude/idmef.h>
 #include <libprelude/prelude-log.h>
 #include <libprelude/idmef-message-id.h>
